@@ -2,8 +2,19 @@
 
 #' Return or set header_n binding
 #'
-#' When the header or table body relies on population count data, the header_n
-#' binding is used for display and calculations.
+#' The `header_n()` functions can be used to automatically pull the header_n
+#' derivations from the table or change them for future use.
+#'
+#' @details
+#' The `header_n` object is created by Tplyr when a table is built and intended
+#' to be used by the `add_column_headers()` function when displaying table level
+#' population totals. These methods are intended to be used for calling the
+#' population totals calculated by Tplyr, and to overwrite them if a user
+#' chooses to.
+#'
+#' If you have a need to change the header Ns that appear in your table headers,
+#' say you know you are working with a subset of the data that doesn't represent
+#' the totals, you can replace the data used with `set_header_n()`.
 #'
 #' @param table A \code{tplyr_table} object
 #'
@@ -12,9 +23,14 @@
 #'   \code{set_tplyr_header_n} the modified object.
 #'
 #' @examples
-#' tab <- tplyr_table(iris, Species)
+#' tab <- tplyr_table(mtcars, gear)
+#'
+#' header_n(tab) <- data.frame(
+#'   gear = c(3, 4, 5),
+#'   n = c(10, 15, 45)
+#' )
+#'
 #'
-#' header_n(tab) <- c(setosa = 50, versicolor = 50, virginica = 50)
 #'
 #' @export
 #' @rdname header_n
@@ -23,8 +39,8 @@ header_n <- function(table) {
 }
 
 #' @param x A \code{tplyr_table} object
-#' @param value A named numeric vector. Names of vector should match treatment
-#'   group names.
+#' @param value A data.frame with columns with the treatment variable, column
+#'   variabes, and a variable with counts named 'n'.
 #'
 #' @export
 #' @rdname header_n
@@ -32,16 +48,18 @@ header_n <- function(table) {
   set_header_n(x, value)
 }
 
-#' @param header_n A named numeric vector. Names of vector should match treatment
-#'   group names.
+#' @param header_n A data.frame with columns with the treatment variable, column
+#'   variabes, and a variable with counts named 'n'.
 #'
 #' @export
 #' @rdname header_n
 set_header_n <- function(table, value) {
-  assert_that(is.numeric(value),
+  assert_that(is.data.frame(value),
                           msg = "header_n argument must be numeric")
 
-  assert_that(!is.null(names(value)),
+  assert_that("n" %in% names(value))
+
+  assert_that(is.numeric(value$n),
               msg = "header_n argument must be named")
 
   env_bind(table, header_n = value)
@@ -318,7 +336,11 @@ get_count_layer_formats <- function(obj) {
 #' @rdname table_format_defaults
 set_count_layer_formats <- function(obj, ...) {
   # Bind the formats into the table
-  env_bind(obj, count_layer_formats = list(...))
+
+  if (length(list(...)) > 0) params <- count_f_str_check(...)
+  else params <- list(...)
+
+  env_bind(obj, count_layer_formats = params)
   obj
 }
 
